@@ -9,7 +9,6 @@ pub type DefaultServerTlsStream = TlsStream<TcpStream>;
 pub type DefaultClientTlsStream = TlsStream<TcpStream>;
 
 pub use connector::*;
-pub use stream::*;
 
 mod split {
 
@@ -136,6 +135,7 @@ mod connector {
         ) -> Result<(BoxWriteConnection, BoxReadConnection, RawFd), IoError> {
             debug!("connect to tls addr: {}", addr);
             let tcp_stream = TcpStream::connect(addr).await?;
+            tcp_stream.set_nodelay(true)?;
             let fd = tcp_stream.as_raw_fd();
 
             debug!("connect to tls domain: {}", self.domain);
@@ -168,13 +168,10 @@ mod connector {
 pub use cert::*;
 
 mod cert {
-    use std::fs::File;
-    use std::io::BufRead;
-    use std::io::BufReader;
     use std::io::Error as IoError;
     use std::io::ErrorKind;
-    use std::path::Path;
 
+    use crate::net::certs::CertBuilder;
     use native_tls::Certificate as NativeCertificate;
     use native_tls::Identity;
     use openssl::pkcs12::Pkcs12;
@@ -183,21 +180,6 @@ mod cert {
     pub type Certificate = openssl::x509::X509;
     pub type PrivateKey = openssl::pkey::PKey<Private>;
 
-    pub trait CertBuilder: Sized {
-        fn new(bytes: Vec<u8>) -> Self;
-
-        fn from_reader(reader: &mut dyn BufRead) -> Result<Self, IoError> {
-            let mut bytes = vec![];
-            reader.read_to_end(&mut bytes)?;
-            Ok(Self::new(bytes))
-        }
-
-        fn from_path(path: impl AsRef<Path>) -> Result<Self, IoError> {
-            let mut reader = BufReader::new(File::open(path)?);
-            Self::from_reader(&mut reader)
-        }
-    }
-
     pub struct X509PemBuilder(Vec<u8>);
 
     impl CertBuilder for X509PemBuilder {
@@ -298,6 +280,7 @@ mod builder {
         pub fn identity(builder: IdentityBuilder) -> Result<Self, IoError> {
             let identity = builder.build()?;
             let connector = TlsConnector::new().identity(identity);
+            //connector.min_protocol_version(Some())
             Ok(Self(connector))
         }
 
@@ -350,6 +333,8 @@ mod builder {
     }
 }
 
+#[deprecated]
+#[allow(deprecated)]
 pub use stream::AllTcpStream;
 
 mod stream {
@@ -363,22 +348,27 @@ mod stream {
     use futures_lite::{AsyncRead, AsyncWrite};
     use pin_project::pin_project;
 
+    #[deprecated]
     #[pin_project(project = EnumProj)]
     pub enum AllTcpStream {
         Tcp(#[pin] TcpStream),
         Tls(#[pin] DefaultClientTlsStream),
     }
 
+    #[allow(deprecated)]
     impl AllTcpStream {
         pub fn tcp(stream: TcpStream) -> Self {
+            #[allow(deprecated)]
             Self::Tcp(stream)
         }
 
         pub fn tls(stream: DefaultClientTlsStream) -> Self {
+            #[allow(deprecated)]
             Self::Tls(stream)
         }
     }
 
+    #[allow(deprecated)]
     impl AsyncRead for AllTcpStream {
         fn poll_read(
             self: Pin<&mut Self>,
@@ -392,6 +382,7 @@ mod stream {
         }
     }
 
+    #[allow(deprecated)]
     impl AsyncWrite for AllTcpStream {
         fn poll_write(
             self: Pin<&mut Self>,
@@ -441,14 +432,16 @@ mod test {
     use tokio_util::codec::Framed;
     use tokio_util::compat::FuturesAsyncReadCompatExt;
 
+    use crate::net::certs::CertBuilder;
     use crate::net::TcpListener;
     use crate::net::TcpStream;
     use crate::test_async;
     use crate::timer::sleep;
 
+    #[allow(deprecated)]
     use super::{
-        AcceptorBuilder, AllTcpStream, CertBuilder, ConnectorBuilder, IdentityBuilder,
-        PrivateKeyBuilder, X509PemBuilder,
+        AcceptorBuilder, AllTcpStream, ConnectorBuilder, IdentityBuilder, PrivateKeyBuilder,
+        X509PemBuilder,
     };
 
     const CA_PATH: &str = "certs/certs/ca.crt";
@@ -617,6 +610,8 @@ mod test {
                 .connect("localhost", tcp_stream)
                 .await
                 .expect("tls failed");
+
+            #[allow(deprecated)]
             let all_stream = AllTcpStream::Tls(tls_stream);
             let mut framed = Framed::new(all_stream.compat(), BytesCodec::new());
             debug!("client: got connection. waiting");
