@@ -10,7 +10,9 @@ mod test;
 
 pub use acceptor::{TlsAcceptor, TlsAcceptorBuilder};
 pub use certificate::Certificate;
-pub use connector::{TlsAnonymousConnector, TlsConnector, TlsConnectorBuilder, TlsDomainConnector};
+pub use connector::{
+    certs, TlsAnonymousConnector, TlsConnector, TlsConnectorBuilder, TlsDomainConnector,
+};
 pub use error::Error as TlsError;
 pub use openssl::ssl::SslVerifyMode;
 pub use stream::{AllTcpStream, TlsStream};
